@@ -350,9 +350,7 @@ sub get_best_url {
 sub assemble_url {
 	my ($package, $uri, @segments) = @_;
 
-	my $path = $uri->path;
-	$path =~ s/\/+$//g;
-	$uri->path(join('/', $path, @segments));
+	$uri->path_segments(grep { length > 0 } $uri->path_segments, @segments);
 
 	return $uri;
 }
